@@ -40,7 +40,6 @@ FAKE_UUID = str(uuid.uuid4())
 FIVE_KB = 5 * units.Ki
 
 VMWARE_DS = {
-    'verbose': True,
     'debug': True,
     'known_stores': ['vmware_datastore'],
     'default_store': 'vsphere',
@@ -48,7 +47,7 @@ VMWARE_DS = {
     'vmware_server_username': 'username',
     'vmware_server_password': 'password',
     'vmware_store_image_dir': '/openstack_glance',
-    'vmware_api_insecure': 'True',
+    'vmware_insecure': 'True',
     'vmware_datastores': ['a:b:0'],
 }
 
@@ -90,7 +89,7 @@ class TestStore(base.StoreBaseTest,
                     vmware_server_username='admin',
                     vmware_server_password='admin',
                     vmware_server_host=VMWARE_DS['vmware_server_host'],
-                    vmware_api_insecure=VMWARE_DS['vmware_api_insecure'],
+                    vmware_insecure=VMWARE_DS['vmware_insecure'],
                     vmware_datastores=VMWARE_DS['vmware_datastores'])
 
         mock_get_datastore.side_effect = fake_datastore_obj
@@ -115,7 +114,7 @@ class TestStore(base.StoreBaseTest,
         with mock.patch('requests.Session.request') as HttpConn:
             HttpConn.return_value = utils.fake_response()
             (image_file, image_size) = self.store.get(loc)
-        self.assertEqual(image_size, expected_image_size)
+        self.assertEqual(expected_image_size, image_size)
         chunks = [c for c in image_file]
         self.assertEqual(expected_returns, chunks)
 
@@ -595,7 +594,7 @@ class TestStore(base.StoreBaseTest,
         with mock.patch('requests.Session.request') as HttpConn:
             HttpConn.side_effect = getresponse
             (image_file, image_size) = self.store.get(loc)
-        self.assertEqual(image_size, expected_image_size)
+        self.assertEqual(expected_image_size, image_size)
         chunks = [c for c in image_file]
         self.assertEqual(expected_returns, chunks)
 
